@@ -35,28 +35,20 @@
 #include <JLib/Util/JString.h>
 #include <JLib/Util/JTextFile.h>
 #include <vector>
-#include <SDL/SDL_endian.h>
 
 class JImage;
 
 /** Devuelve la palabra (32) menos significativa */
-#if SDL_BYTEORDER == SDL_LIL_ENDIAN
 #define JLOWORD(x) ((x) & 0x0000FFFF)
+
 /** Devuelve la palabra ms significativa */
 #define JHIWORD(x) ((x) & 0xFFFF0000)
+
 /** Devuelve el byte menos significativo */
 #define JLOBYTE(x) ((x) & 0x00FF)
+
 /** Devuelve el byte ms significativo */
 #define JHIBYTE(x) ((x) & 0xFF00)
-#else
-#define JLOWORD(x) ((x) & 0xFFFF0000)
-/** Devuelve la palabra ms significativa */
-#define JHIWORD(x) ((x) & 0x0000FFFF)
-/** Devuelve el byte menos significativo */
-#define JLOBYTE(x) ((x) & 0xFF00)
-/** Devuelve el byte ms significativo */
-#define JHIBYTE(x) ((x) & 0x00FF)
-#endif
 
 /** Devuelve el mnimo entre dos nmeros. 
  * @param a Primer nmero.
@@ -153,7 +145,7 @@ inline void JClamp(float& v, float min, float max)
  * deben ser caracteres de 8x8 organizados en 16 filas por 16 columnas.
  * @param outFileName Nombre del fichero de salida.
  */
-void DumpTGAFontBits(const s8 *TGAFileName, const s8 *outFileName);
+void JDumpTGAFontBits(const s8 *TGAFileName, const s8 *outFileName);
 
 /** Modo grfico.
  */
@@ -180,6 +172,6 @@ JVideoMode * JListVideoModes(s32 *count, s32 depth = 0);
  * @param  img Imagen a examinar.
  * @param  n Nmero de pxeles a mostrar.
  */
-void DumpImage(JImage *img, s32 n = 10);
+void JDumpImage(JImage *img, s32 n = 10);
 
 #endif  // _JUTIL_INCLUDED
