@@ -554,6 +554,7 @@ bool HCApp::InitIntro()
 	SDL_Color fg = {0xff, 0xcc, 0x00, 0x00}, bg = {0x00, 0x00, 0x00, 0x00};
 
 	imgIntro = new JImage;
+	imgFatalFun = new JImage;
 	
 	char str[256];
 	snprintf(str, sizeof(str) - 1, HC_DATA_DIR "intro/%s/intro.txt", preferences.LangCodes()[preferences.CurLang()]);
@@ -569,6 +570,7 @@ bool HCApp::InitIntro()
 	}
 
 	if (imgIntro->Load(HC_DATA_DIR "intro/intro.tga", true) &&
+			imgFatalFun->Load(HC_DATA_DIR "intro/ff.tga", true, 0x0000ffff) &&
 			0 != (textIntro = fontMedium.RenderTextShaded(str, fg, bg)))
 	{
 		if (imgIntro->Width() > width)
@@ -589,12 +591,30 @@ bool HCApp::InitIntro()
 				imgIntro = tmp;
 		}
 
+		if (imgFatalFun->Width() > width)
+		{
+			float w = float(imgFatalFun->Width());
+			do 
+			{
+				w /= 1.5f;
+			}
+			while (w > Width());
+			
+			JImage *tmp = imgFatalFun;
+			imgFatalFun = imgFatalFun->Scale(w/float(imgFatalFun->Width()), w/float(imgFatalFun->Width()));
+			
+			if (imgFatalFun)
+				delete tmp;
+			else
+				imgFatalFun = tmp;
+		}
+
 		imgIntro->Alpha(0);
+		imgFatalFun->Alpha(0);
 		textIntro->Alpha(0);
-		imgIntro->Pos(((width - imgIntro->Width())/2),
-									((height - imgIntro->Height())/2));
-		textIntro->Pos(((width - textIntro->Width())/2),
-									 ((imgIntro->Y() + imgIntro->Height()) + (height - (imgIntro->Y() + imgIntro->Height()) - textIntro->Height())/2));
+		imgIntro->Pos(((width - imgIntro->Width())/2), ((height - imgIntro->Height())/2));
+		imgFatalFun->Pos(((width - imgFatalFun->Width())/2), ((height - imgFatalFun->Height())/2));
+		textIntro->Pos(((width - textIntro->Width())/2), ((imgIntro->Y() + imgIntro->Height()) + (height - (imgIntro->Y() + imgIntro->Height()) - textIntro->Height())/2));
 
 		timerGeneral.Start(1000);
 
@@ -744,8 +764,8 @@ bool HCApp::InitCredits()
 																							 "Drawing\nJuan Carlos Seijo Pérez",
 																							 "Animation\nJuan Carlos Seijo Pérez",
 																							 "Music\nJuan Carlos Seijo Pérez",
-																							 "Thanks for playing!\nCheck for more games at\nwww.mainreactor.net",
-																							 "Holotz's Castle\n(C) Juan Carlos Seijo Pérez 2004",
+																							 "Thanks for playing!\nCheck for more games at\nwww.mainreactor.net\n&\nwww.FatalFun.com",
+																							 "Holotz's Castle\n(C) Juan Carlos Seijo Pérez 2004-2007",
 																							 ACKNOWLEDGEMENTS};
 
 	bool ok;
@@ -1153,9 +1173,23 @@ bool HCApp::DrawPaused()
 
 bool HCApp::DrawIntro()
 {
-	SDL_FillRect(screen, 0, 0);
-	imgIntro->Draw();
-	textIntro->Draw();
+	if (timerGeneral.TotalLap() < 6000)
+	{
+		SDL_FillRect(screen, 0, SDL_MapRGB(screen->format, 255, 255, 255));
+		imgFatalFun->Draw();
+	}
+	else
+	if (timerGeneral.TotalLap() < 7000)
+	{
+		int a = 255 - ((timerGeneral.TotalLap()-6000)*255)/1000;
+		SDL_FillRect(screen, 0, SDL_MapRGB(screen->format, a, a, a));
+	}
+	else
+	{
+		SDL_FillRect(screen, 0, 0);
+		imgIntro->Draw();
+		textIntro->Draw();
+	}
 	
 	Flip();
 	
@@ -1352,7 +1386,7 @@ bool HCApp::UpdatePaused()
 
 bool HCApp::UpdateIntro()
 {
-	if (timerGeneral.TotalLap() > 7000)
+	if (timerGeneral.TotalLap() > 10000)
 	{
 		if (imgIntro->Alpha() > 0)
 		{
@@ -1372,6 +1406,7 @@ bool HCApp::UpdateIntro()
 		}
 	}
 	else
+	if (timerGeneral.TotalLap() > 7000)
 	{
 		if (imgIntro->Alpha() < 255)
 		{
@@ -1380,7 +1415,7 @@ bool HCApp::UpdateIntro()
 		}
 		else
 		{
-			if (timerGeneral.TotalLap() > 1000)
+			if (timerGeneral.TotalLap() > 8000)
 			{
 				if (textIntro->Alpha() < 255)
 				{
@@ -1390,6 +1425,25 @@ bool HCApp::UpdateIntro()
 			}
 		}
 	}
+	else
+	if (timerGeneral.TotalLap() > 5000)
+	{
+		if (imgFatalFun->Alpha() > 0)
+		{
+			// Fades out
+			imgFatalFun->Alpha(imgFatalFun->Alpha() - 15);
+			
+			return true;
+		}
+	}
+	else
+	{
+		if (imgFatalFun->Alpha() < 255)
+		{
+			// Fades in the intro image
+			imgFatalFun->Alpha(imgFatalFun->Alpha() + 15);
+		}
+	}
 
   return true;
 }
