@@ -56,11 +56,11 @@ class HCEnemyChaser;
 "Carlos & Julia & Jorge & Jose\n"\
 "Ana & Nathan & María & Marco,\n"\
 "Jorge & Amelia & Alejandro,\n"\
-"Carlos & Vero & Álvaro, Edu & Vero,\n"\
-"Alex, Chily, Santos & Rocío, Felix &\n"\
+"Carlos & Vero & Álvaro & Irene, Edu & Vero,\n"\
+"Alex, Chily, Santos & Rocío, Félix &\n"\
 "Carmen, Ossuna's, Jose & Gloria, Ori &\n"\
 "Loli, Diana & David, Luis,\n"\
-"Angel, Celia, Iñigo,\n"\
+"Ángel, Celia, Íñigo,\n"\
 "Markus Rath/Ronny Standtke (German translation),\n"\
 "Milan Babuškov (Add-on levels),\n"\
 "Miriam Ruiz (Debian package),\n"\
@@ -72,7 +72,8 @@ class HCEnemyChaser;
 "Filip (Triple T) Bártek (Czech translation)\n"\
 "Pierre-Paul Lavoie (FreeBSD porting)\n"\
 "Filipe Silva (Portuguese translation)\n"\
-"Ben Wong (English translation, patches)"
+"Ben Wong (English translation, patches)\n"\
+"Federico 'hs1' Tolomei (Italian translation)"
 
 /** Possible states of the game.
  */
@@ -145,6 +146,7 @@ class HCApp : public JApp
 
 	JTimer timerGeneral;                  /**< Timer for general use. */
 	JImage *imgIntro;                     /**< Intro image (MainReactor). */
+	JImage *imgFatalFun;                  /**< Intro image (Fatalfun). */
 	JImage *textIntro;                    /**< Intro text (Presents...). */
 
 	HCLevel level;                        /**< Game level. */
